==> evolution-2.31.1.tar.bz2: evolution-2.31.1/modules/calendar/e-memo-shell-backend.h <==
/*
 * e-memo-shell-backend.h
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) version 3.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with the program; if not, see <http://www.gnu.org/licenses/>
 *
 *
 * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
 *
 */

#ifndef E_MEMO_SHELL_BACKEND_H
#define E_MEMO_SHELL_BACKEND_H

#include <shell/e-shell-backend.h>
#include <libedataserver/e-source-list.h>

/* Standard GObject macros */
#define E_TYPE_MEMO_SHELL_BACKEND \
	(e_memo_shell_backend_get_type ())
#define E_MEMO_SHELL_BACKEND(obj) \
	(G_TYPE_CHECK_INSTANCE_CAST \
	((obj), E_TYPE_MEMO_SHELL_BACKEND, EMemoShellBackend))
#define E_MEMO_SHELL_BACKEND_CLASS(cls) \
	(G_TYPE_CHECK_CLASS_CAST \
	((cls), E_TYPE_MEMO_SHELL_BACKEND, EMemoShellBackendClass))
#define E_IS_MEMO_SHELL_BACKEND(obj) \
	(G_TYPE_CHECK_INSTANCE_TYPE \
	((obj), E_TYPE_MEMO_SHELL_BACKEND))
#define E_IS_MEMO_SHELL_BACKEND_CLASS(cls) \
	(G_TYPE_CHECK_CLASS_TYPE \
	((cls), E_TYPE_MEMO_SHELL_BACKEND))
#define E_MEMO_SHELL_BACKEND_GET_CLASS(obj) \
	(G_TYPE_INSTANCE_GET_CLASS \
	((obj), E_TYPE_MEMO_SHELL_BACKEND, EMemoShellBackendClass))

G_BEGIN_DECLS

typedef struct _EMemoShellBackend EMemoShellBackend;
typedef struct _EMemoShellBackendClass EMemoShellBackendClass;
typedef struct _EMemoShellBackendPrivate EMemoShellBackendPrivate;

struct _EMemoShellBackend {
	EShellBackend parent;
	EMemoShellBackendPrivate *priv;
};

struct _EMemoShellBackendClass {
	EShellBackendClass parent_class;
};

GType		e_memo_shell_backend_get_type	(void);
void		e_memo_shell_backend_register_type
					(GTypeModule *type_module);
ESourceList *	e_memo_shell_backend_get_source_list
					(EMemoShellBackend *memo_shell_backend);

G_END_DECLS

#endif /* E_MEMO_SHELL_BACKEND_H */

==> evolution-3.1.2.tar.bz2: evolution-3.1.2/modules/calendar/e-memo-shell-backend.h <==
/*
 * e-memo-shell-backend.h
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) version 3.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with the program; if not, see <http://www.gnu.org/licenses/>
 *
 *
 * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
 *
 */

#ifndef E_MEMO_SHELL_BACKEND_H
#define E_MEMO_SHELL_BACKEND_H

#include <shell/e-shell-backend.h>
#include <libedataserver/e-source-list.h>

/* Standard GObject macros */
#define E_TYPE_MEMO_SHELL_BACKEND \
	(e_memo_shell_backend_get_type ())
#define E_MEMO_SHELL_BACKEND(obj) \
	(G_TYPE_CHECK_INSTANCE_CAST \
	((obj), E_TYPE_MEMO_SHELL_BACKEND, EMemoShellBackend))
#define E_MEMO_SHELL_BACKEND_CLASS(cls) \
	(G_TYPE_CHECK_CLASS_CAST \
	((cls), E_TYPE_MEMO_SHELL_BACKEND, EMemoShellBackendClass))
#define E_IS_MEMO_SHELL_BACKEND(obj) \
	(G_TYPE_CHECK_INSTANCE_TYPE \
	((obj), E_TYPE_MEMO_SHELL_BACKEND))
#define E_IS_MEMO_SHELL_BACKEND_CLASS(cls) \
	(G_TYPE_CHECK_CLASS_TYPE \
	((cls), E_TYPE_MEMO_SHELL_BACKEND))
#define E_MEMO_SHELL_BACKEND_GET_CLASS(obj) \
	(G_TYPE_INSTANCE_GET_CLASS \
	((obj), E_TYPE_MEMO_SHELL_BACKEND, EMemoShellBackendClass))

G_BEGIN_DECLS

typedef struct _EMemoShellBackend EMemoShellBackend;
typedef struct _EMemoShellBackendClass EMemoShellBackendClass;
typedef struct _EMemoShellBackendPrivate EMemoShellBackendPrivate;

struct _EMemoShellBackend {
	EShellBackend parent;
	EMemoShellBackendPrivate *priv;
};

struct _EMemoShellBackendClass {
	EShellBackendClass parent_class;
};

GType		e_memo_shell_backend_get_type	(void);
void		e_memo_shell_backend_register_type
					(GTypeModule *type_module);
ESourceList *	e_memo_shell_backend_get_source_list
					(EMemoShellBackend *memo_shell_backend);
GSList *	e_memo_shell_backend_get_selected_memo_lists
					(EMemoShellBackend *memo_shell_backend);
void		e_memo_shell_backend_set_selected_memo_lists
					(EMemoShellBackend *memo_shell_backend,
					 GSList *selected_memo_lists);

G_END_DECLS

#endif /* E_MEMO_SHELL_BACKEND_H */
